std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >         -> std::string
std::__detail::_Node_iterator<std::pair<unsigned long const, Record*>, false, false>    -> RecordMap::iterator
[abi:cxx11]                                                                             ->
std::unique_ptr<Record, std::default_delete<Record> >                                   -> RecordPtr
